""" Python XML Templating Language

Modules in this package:

reference   - reference implementation
optimised   - optimised implementation
resolvers   - resource indirection
exceptions  - shared exceptions for implementations

constants   - global constants/fixes for all modules
serialisers - write DOM trees in various formats
utilities   - general-purpose helper functions
error       - error page template
pxdom       - stand-alone pure-Python DOM Level 3 implementation

Functions at pxtl module level:

processURI, processFile, processString - main interface, goes to optimised
encodeText, decodeName  - string-processing utilities

Example usage:

import pxtl
templatepath= os.path.join(templatedir, 'items.px')
scope= { 'itemsToShow': 3 }
pxtl.processFile(template, globals= scope)
"""

__version__= 2,0
__author__ = 'Andrew Clover <and@doxdesk.com>'

import sys
assert sys.version_info>= (2,2), 'pxtl 2.0 and later requires Python 2.2 or later. Use pxtl 1.9 for older installs.'

__all__= [
  # package modules
  'reference', 'optimised',
  'resolvers', 'exceptions',
  'serialisers', 'utilities',
  'constants', 'error',
  'pxdom',
  # main interface from pxtl.optimised
  'processURI', 'processFile', 'processString',
  # from pxtl.utilities
  'encodeText', 'decodeName',
]

from pxtl.optimised import processURI, processFile, processString
from pxtl.utilities import encodeText, decodeName


# Run as script
#
__usage__= 'Usage: python __init__.py [-d] template.px'

if __name__=='__main__':
  import sys
  if len(sys.argv)<2:
    sys.stderr.write(__usage__+'\n')
    sys.exit(-1)
  processFile(sys.argv[-1], debug= ('-d' in sys.argv[1:-1]), headers= True)
